==> lxqt-notificationd_2.2.0.orig.tar.xz: lxqt-notificationd-2.2.0/config/translations/lxqt-config-notificationd_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Use the top of the notification as shown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these notifications:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Duration</source>
        <translation>Durada</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="79"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="91"/>
        <source>Default duration:</source>
        <translation>Durada predeterminada&#x202f;:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="98"/>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="126"/>
        <source>Screen</source>
        <translation>Ecran</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="132"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>Show notifications on screen with the mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="145"/>
        <source>Do Not Disturb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="151"/>
        <source>Only save notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Talhas</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Largor&#x202f;:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Espaci&#x202f;:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_2.3.0.orig.tar.xz: lxqt-notificationd-2.3.0/config/translations/lxqt-config-notificationd_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="85"/>
        <location filename="../advancedsettings.ui" line="95"/>
        <source>Use the top of the notification as shown.</source>
        <translation>Utilizar la part superiora de la notificacion coma mostrat.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="88"/>
        <source>Ignore these notifications:</source>
        <translation>Ignorar aquestas notificacions :</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Duration</source>
        <translation>Durada</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="29"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>D’unas notificacions possedisson lor pròprias durada d’afichatge.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="41"/>
        <source>Default duration:</source>
        <translation>Durada predeterminada&#x202f;:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="48"/>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="129"/>
        <source>Screen</source>
        <translation>Ecran</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Quand la casa es marcada, las notificacions se mostraràn totjorn a l’ecran principal</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="138"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Mostrar las notificacions a l’ecran ont se tròba la mirga</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="113"/>
        <source>Do Not Disturb</source>
        <translation>Destorbar pas</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="119"/>
        <source>Only save notifications</source>
        <translation>Enregistrar solament las notificacions</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="63"/>
        <source>Unattended Notifications</source>
        <translation>Notificacions non consultadas</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="71"/>
        <source>How many to save:</source>
        <translation>Quantas enregistrar :</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Talhas</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Largor&#x202f;:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Espaci&#x202f;:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Posicion a l’ecran</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Apercebut</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Avertiment :&lt;/b&gt; lo demòni de notificacions reagís lentament.
Ensag de connexion en cors…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Avertiment :&lt;/b&gt; cap de demòni de notificacions es pas en execucion.
S&apos;utilizarà una solucion de substitucion.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Avertiment :&lt;/b&gt; un demòni de notificacions tèrç (%1) es en cors d&apos;execucion.
Aquestes paramètres auràn pas cap d&apos;efièch sus el !</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>ennaut a esquèrra</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>ennaut al centre</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>ennaut a drecha</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>al centre a esquèrra</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>al centre a drecha</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>enbàs a esquèrra</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>enbàs al centre</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>enbàs a drecha</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Demostracion de notificacion </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Aquò es una notificacion de pròva.
D&apos;ara enlà, totas las notificacions apareisseràn aicí sus LXQt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Notificacions del burèu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Paramètres generals</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Aparéncia</translation>
    </message>
</context>
</TS>
